@@ -59,6 +59,7 @@ impl Iterator for CircleCircumferenceLinesIterator {
 #[cfg(test)]
 mod iterator {
     use super::*;
+    use crate::geom::testing_utils::assert_approx_line_eq;
 
     #[test]
     fn it_should_return_num_of_points_requested() {
@@ -76,21 +77,42 @@ mod iterator {
 
     #[test]
     fn it_should_return_all_points_of_a_circle() {
-        let iterator = CircleCircumferenceLinesIterator::new(Circle(Point(10.0, 20.0), 5.0), 8);
-
+        let circle: Circle<f32> = Circle(Point(10.0, 20.0), 5.0);
+        let iterator = CircleCircumferenceLinesIterator::new(circle, 8);
         let points: Vec<Line<f32>> = iterator.collect();
-        assert_eq!(
-            points,
-            vec![
-                Line(Point(10.0, 25.0), Point(13.535534, 23.535534),),
-                Line(Point(13.535534, 23.535534), Point(15.0, 20.0),),
-                Line(Point(15.0, 20.0), Point(13.535534, 16.464466),),
-                Line(Point(13.535534, 16.464466), Point(10.0, 15.0),),
-                Line(Point(10.0, 15.0), Point(6.464466, 16.464466),),
-                Line(Point(6.464466, 16.464466), Point(5.0, 20.0),),
-                Line(Point(5.0, 20.0), Point(6.4644666, 23.535534),),
-                Line(Point(6.4644666, 23.535534), Point(10.0, 25.0),),
-            ]
+
+        assert_eq!(points.len(), 8);
+        assert_approx_line_eq(
+            points[0],
+            Line(Point(10.0, 25.0), Point(13.535534, 23.535534)),
+        );
+        assert_approx_line_eq(
+            points[1],
+            Line(Point(13.535534, 23.535534), Point(15.0, 20.0)),
+        );
+        assert_approx_line_eq(
+            points[2],
+            Line(Point(15.0, 20.0), Point(13.535534, 16.464466)),
+        );
+        assert_approx_line_eq(
+            points[3],
+            Line(Point(13.535534, 16.464466), Point(10.0, 15.0)),
+        );
+        assert_approx_line_eq(
+            points[4],
+            Line(Point(10.0, 15.0), Point(6.464466, 16.464466)),
+        );
+        assert_approx_line_eq(
+            points[5],
+            Line(Point(6.464466, 16.464466), Point(5.0, 20.0)),
+        );
+        assert_approx_line_eq(
+            points[6],
+            Line(Point(5.0, 20.0), Point(6.4644666, 23.535534)),
+        );
+        assert_approx_line_eq(
+            points[7],
+            Line(Point(6.4644666, 23.535534), Point(10.0, 25.0)),
         );
     }
 }
