@@ -387,7 +387,7 @@ where
     }
 
     pub fn step_direction(self) -> Point<<N as ToSignedClamped>::Output> {
-        self.diff().to_point().sign()
+        self.diff().to_point().step()
     }
 }
 
@@ -1091,3 +1091,17 @@ mod flip {
         assert_eq!(line.flip(), Line(Point(987, 654), Point(123, 456)))
     }
 }
+
+#[cfg(test)]
+mod step_direction {
+    use super::*;
+
+    #[test]
+    fn it_should_return_zero_for_no_direction() {
+        let point: Point<f32> = Point(0.0, 0.0);
+        let line = Line(point, point);
+
+        let step_direction = line.step_direction();
+        assert_eq!(Point(0.0_f32, 0.0_f32), step_direction);
+    }
+}
